@@ -1,7 +1,7 @@
 """DB-SIG compliant module for communicating with MS SQL servers"""
 
 __author__ = 'Mikhail Denisenko <denisenkom@gmail.com>'
-__version__ = '1.6.11'
+__version__ = '1.6.12'
 
 import logging
 import six
@@ -344,6 +344,9 @@ class _Connection(object):
     def _try_activate_cursor(self, cursor):
         if cursor is not self._active_cursor:
             session = self._active_cursor._session
+            if session.in_cancel:
+                session.process_cancel()
+
             if session.state == TDS_PENDING:
                 raise InterfaceError('Results are still pending on connection')
             self._active_cursor = cursor
